import { createApp, h } from 'vue';
import MessageBar from '@/components/MessageBar.vue';
import ConfirmDialog from '@/components/ConfirmDialog.vue';

const MessagePlugin = {
  install(app) {
    const showMessage = (type, message, action) => {
      const container = document.createElement('div');
      container.style.position = 'fixed';
      container.style.bottom = '20px';
      container.style.right = '20px';
      document.body.appendChild(container);

      const appInstance = createApp({
        render() {
          return h(MessageBar, { type, message, action });
        },
      });

      appInstance.mount(container);

      setTimeout(() => {
        appInstance.unmount();
        document.body.removeChild(container);
      }, 5000); // 自动卸载组件
    };

    const showConfirm = (message, onConfirm, onCancel) => {
      const container = document.createElement('div');
      container.style.position = 'fixed';
      container.style.top = '50%';
      container.style.left = '50%';
      container.style.transform = 'translate(-50%, -50%)';
      document.body.appendChild(container);

      const appInstance = createApp({
        render() {
          return h(ConfirmDialog, {
            message,
            onConfirm: () => {
              onConfirm();
              appInstance.unmount();
              document.body.removeChild(container);
            },
            onCancel: () => {
              onCancel();
              appInstance.unmount();
              document.body.removeChild(container);
            },
          });
        },
      });

      appInstance.mount(container);
    };

    app.config.globalProperties.$message = {
      info: (message, action) => showMessage('info', message, action),
      danger: (message, action) => showMessage('danger', message, action),
      warning: (message, action) => showMessage('warning', message, action),
      confirm: (message, onConfirm, onCancel) => showConfirm(message, onConfirm, onCancel),
    };
  },
};

export default MessagePlugin;
